# CPANLP: Certified Public Accountant Natural Language Processing toolkit
Redefining [Accounting](https://cpanlp.com/overview/redefine)!
Under construction! Not ready for use yet! Currently experimenting and planning!
Developed by **Bfsu Intelligent Accounting Team** (c) 2023

## How to install
```python
pip install cpanlp
```

## Examples of How To Use
Creating A Server
```python
import cpanlp as cp
```


Check out: https://cpanlp.com